@@ -185,7 +185,8 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	(_tmp2 = self->priv->_size++, self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1));
+	_tmp2 = self->priv->_size++;
+	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
 	self->priv->_stamp++;
 	return TRUE;
 }
@@ -274,7 +275,10 @@ static void gee_array_list_set_capacity (GeeArrayList* self, gint value) {
 	gint _tmp0;
 	g_return_if_fail (GEE_IS_ARRAY_LIST (self));
 	g_assert (value >= self->priv->_size);
-	(_tmp0 = value, self->priv->_items = g_renew (gpointer, self->priv->_items, value), (_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL), self->priv->_items_length1 = _tmp0);
+	_tmp0 = value;
+	self->priv->_items = g_renew (gpointer, self->priv->_items, value);
+	(_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL);
+	self->priv->_items_length1 = _tmp0;
 }
 
 
@@ -504,7 +508,7 @@ static void gee_array_list_init (GeeArrayList * self) {
 static void gee_array_list_dispose (GObject * obj) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (obj);
-	(self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) self->priv->g_destroy_func)), NULL));
+	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) self->priv->g_destroy_func)), NULL);
 	G_OBJECT_CLASS (gee_array_list_parent_class)->dispose (obj);
 }
 
